@@ -1,4 +1,4 @@
-# @(#)$Id: Bob.pm 353 2012-03-29 12:18:29Z pjf $
+# @(#)$Id: Bob.pm 364 2012-04-15 18:09:42Z pjf $
 
 package Bob;
 
@@ -12,7 +12,7 @@ BEGIN {
    my $reason; $reason = CPANTesting::broken_toolchain and whimper $reason;
 }
 
-use version; our $VERSION = qv( '1.2' );
+use version; our $VERSION = qv( '1.3' );
 
 use File::Spec::Functions;
 use Module::Build;
@@ -24,20 +24,12 @@ sub new {
 
    $] < $perl_ver and whimper "Perl minimum ${perl_ver}";
 
-   my $module     = $params->{module} or whimper 'No module name';
-   my $distname   = $module; $distname =~ s{ :: }{-}gmx;
-   my $class_path = catfile( q(lib), split m{ :: }mx, $module.q(.pm) );
-   my $sub_class  = Module::Build->subclass( code => q{
-      sub ACTION_distmeta {
-         my $self = shift; use Pod::Select;
+   my $module      = $params->{module} or whimper 'No module name';
+   my $distname    = $module; $distname =~ s{ :: }{-}gmx;
+   my $class_path  = catfile( q(lib), split m{ :: }mx, $module.q(.pm) );
+   my $build_class = __get_build_class( $params );
 
-         $self->notes->{create_readme_pod} and podselect( {
-            -output => q(README.pod) }, $self->dist_version_from );
-
-         return $self->SUPER::ACTION_distmeta;
-      } }, );
-
-   return $sub_class->new
+   return $build_class->new
       ( add_to_cleanup     => [ q(Debian_CPANTS.txt), $distname.q(-*),
                                 map { ( q(*/) x $_ ).q(*~) } 0..5 ],
         build_requires     => $params->{build_requires},
@@ -61,6 +53,26 @@ sub new {
 sub __cpan_testing { !! ($ENV{AUTOMATED_TESTING} || $ENV{PERL_CR_SMOKER_CURRENT}
                      || ($ENV{PERL5OPT} || q()) =~ m{ CPAN-Reporter }mx) }
 
+sub __get_build_class {
+   # Which subclass of M::B should we create?
+   my $params = shift;
+
+   exists $params->{build_class} and return $params->{build_class};
+
+   return Module::Build->subclass( code => q{
+      use Pod::Select;
+
+      sub ACTION_distmeta {
+         my $self = shift;
+
+         $self->notes->{create_readme_pod} and podselect( {
+            -output => q(README.pod) }, $self->dist_version_from );
+
+         return $self->SUPER::ACTION_distmeta;
+      }
+   }, );
+}
+
 sub __get_no_index {
    my $params = shift;
 
@@ -68,7 +80,8 @@ sub __get_no_index {
 }
 
 sub __get_notes {
-   my $params = shift; my $notes = $params->{notes} || {};
+   my $params = shift;
+   my $notes  = exists $params->{notes} ? $params->{notes} : {};
 
    $notes->{create_readme_pod} = $params->{create_readme_pod} || 0;
    $notes->{stop_tests       } = __stop_tests( $params );
