@@ -1,47 +1,43 @@
-# @(#)$Id: IO.pm 351 2012-03-28 23:57:08Z pjf $
+# @(#)$Id: IO.pm 368 2012-04-17 18:54:37Z pjf $
 
 package File::DataClass::IO;
 
 use strict;
 use namespace::clean -except => 'meta';
 use overload '""' => sub { shift->pathname }, fallback => 1;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 351 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 368 $ =~ /\d+/gmx );
 
 use Moose;
+use File::DataClass::Constants;
 use Moose::Util::TypeConstraints;
 use English      qw( -no_match_vars );
 use Fcntl        qw( :flock :seek );
 use List::Util   qw( first );
+use Scalar::Util qw( blessed );
 use File::Basename ();
 use File::Copy     ();
 use File::Path     ();
 use File::Spec     ();
 use File::Temp     ();
-use IO::Dir;
 use IO::File;
-use Scalar::Util qw( blessed );
-use File::DataClass::Constants;
-use File::DataClass::Exception;
+use IO::Dir;
 
 use Sub::Exporter -setup => {
    exports => [ qw(io) ], groups => { default => [ qw(io) ], },
 };
 
-subtype 'F_DC_IO_Exception' => as 'ClassName' =>
-   where   { $_->can( q(throw) ) } =>
-   message { "Class $_ is not loaded or has no throw method" };
-
-enum 'F_DC_IO_Mode'    => qw(a a+ r r+ w w+);
-enum 'F_DC_IO_Type'    => qw(dir file);
+enum 'File::DataClass::IO_Mode' => qw(a a+ r r+ w w+);
+enum 'File::DataClass::IO_Type' => qw(dir file);
 
 has 'autoclose'        => is => 'rw', isa => 'Bool',      default    => TRUE  ;
 has 'io_handle'        => is => 'rw', isa => 'Maybe[Object]'                  ;
 has 'is_open'          => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has 'is_utf8'          => is => 'rw', isa => 'Bool',      default    => FALSE ;
-has 'mode'             => is => 'rw', isa => 'F_DC_IO_Mode', default => q(r)  ;
+has 'mode'             => is => 'rw', isa => 'File::DataClass::IO_Mode',
+   default             => q(r);
 has 'name'             => is => 'rw', isa => 'Str',       default    => NUL   ;
 has 'sort'             => is => 'rw', isa => 'Bool',      default    => TRUE  ;
-has 'type'             => is => 'rw', isa => 'Maybe[F_DC_IO_Type]'            ;
+has 'type'             => is => 'rw', isa => 'Maybe[File::DataClass::IO_Type]';
 has '_assert'          => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has '_atomic'          => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has '_atomic_infix'    => is => 'rw', isa => 'Str',       default    => q(B_*);
@@ -52,9 +48,6 @@ has '_chomp'           => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has '_deep'            => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has '_dir_pattern'     => is => 'ro', isa => 'RegexpRef', lazy_build => TRUE  ;
 has '_encoding'        => is => 'rw', isa => 'Str',       default    => NUL   ;
-has '_exception_class' => is => 'rw', isa => 'F_DC_IO_Exception',
-   default             => q(File::DataClass::Exception),
-   writer              => 'exception_class';
 has '_filter'          => is => 'rw', isa => 'Maybe[CodeRef]'                 ;
 has '_lock'            => is => 'rw', isa => 'Bool',      default    => FALSE ;
 has '_lock_obj'        => is => 'rw', isa => 'Maybe[Object]',
@@ -62,7 +55,7 @@ has '_lock_obj'        => is => 'rw', isa => 'Maybe[Object]',
 has '_perms'           => is => 'rw', isa => 'Num',       default    => PERMS ;
 has '_separator'       => is => 'rw', isa => 'Str',       default    => $RS   ;
 has '_umask'           => is => 'rw', isa => 'ArrayRef[Num]',
-   default             => sub { return [] }                                   ;
+   default             => sub { [] };
 
 around BUILDARGS => sub {
    my ($next, $class, $name, $mode, $perms) = @_; my $attrs = {};
@@ -148,15 +141,15 @@ sub assert_dirpath {
 
    $self->_umask_pop;
 
-   -d $dir_name or $self->throw( error => 'Path [_1] cannot create: [_2]',
-                                 args  => [ $dir_name, $ERRNO ] );
+   -d $dir_name or $self->_throw( error => 'Path [_1] cannot create: [_2]',
+                                  args  => [ $dir_name, $ERRNO ] );
    return $dir_name;
 }
 
 sub assert_filepath {
    my $self = shift; my $dir;
 
-   $self->name or $self->throw( 'Path not specified' );
+   $self->name or $self->_throw( 'Path not specified' );
 
    (undef, $dir) = File::Spec->splitpath( $self->name );
 
@@ -303,14 +296,14 @@ sub _constructor {
 }
 
 sub copy {
-   my ($self, $to) = @_; $to or $self->throw( 'Copy requires two args' );
+   my ($self, $to) = @_; $to or $self->_throw( 'Copy requires two args' );
 
    (blessed $to and $to->isa( __PACKAGE__ ))
       or $to = $self->_constructor( $to );
 
    File::Copy::copy( $self->name, $to->pathname )
-      or $self->throw( error => 'Cannot copy [_1] to [_2]',
-                       args  => [ $self->name, $to->pathname ] );
+      or $self->_throw( error => 'Cannot copy [_1] to [_2]',
+                        args  => [ $self->name, $to->pathname ] );
 
    return $to;
 }
@@ -357,8 +350,8 @@ sub empty {
    my $self = shift;
 
    $self->is_file and return -z $self->name;
-   $self->is_dir  or  $self->throw( error => 'Path [_1] not found',
-                                    args  => [ $self->name ] );
+   $self->is_dir  or  $self->_throw( error => 'Path [_1] not found',
+                                     args  => [ $self->name ] );
 
    return $self->next ? FALSE : TRUE;
 }
@@ -367,7 +360,7 @@ sub encoding {
    my ($self, $encoding) = @_;
 
    $encoding or
-      $self->throw( 'No encoding value passed to '.__PACKAGE__.'::encoding' );
+      $self->_throw( 'No encoding value passed to '.__PACKAGE__.'::encoding' );
    $self->is_open and CORE::binmode( $self->io_handle, ":$encoding" );
    $self->_encoding( $encoding );
    $self->is_utf8( $encoding eq q(utf8) ? TRUE : FALSE );
@@ -379,7 +372,7 @@ sub error_check {
 
    $self->io_handle->can( q(error) ) or return;
    $self->io_handle->error or return;
-   $self->throw( error => 'IO error [_1]', args => [ $ERRNO ] );
+   $self->_throw( error => 'IO error [_1]', args => [ $ERRNO ] );
    return;
 }
 
@@ -541,8 +534,8 @@ sub mkdir {
 
    $self->_umask_pop;
 
-   -d $self->name or $self->throw( error => 'Path [_1] cannot create: [_2]',
-                                   args  => [ $self->name, $ERRNO ] );
+   -d $self->name or $self->_throw( error => 'Path [_1] cannot create: [_2]',
+                                    args  => [ $self->name, $ERRNO ] );
    return $self;
 }
 
@@ -561,8 +554,8 @@ sub mkpath {
 
    $self->_umask_pop;
 
-   -d $self->name or $self->throw( error => 'Path [_1] cannot create: [_2]',
-                                   args  => [ $self->name, $ERRNO ] );
+   -d $self->name or $self->_throw( error => 'Path [_1] cannot create: [_2]',
+                                    args  => [ $self->name, $ERRNO ] );
    return $self;
 }
 
@@ -602,7 +595,7 @@ sub open {
 sub _open_args {
    my ($self, $mode, $perms) = @_;
 
-   $self->name or $self->throw( 'Path not specified' );
+   $self->name or $self->_throw( 'Path not specified' );
 
    my $pathname = $self->_atomic && !$self->is_reading( $mode )
                 ? $self->_get_atomic_path : $self->name;
@@ -617,8 +610,8 @@ sub _open_dir {
 
    $self->_assert and $self->assert_dirpath( $path );
    $self->io_handle( IO::Dir->new( $path ) )
-      or $self->throw( error => 'Directory [_1] cannot open',
-                       args  => [ $path ], level => 6 );
+      or $self->_throw( error => 'Directory [_1] cannot open',
+                        args  => [ $path ], level => 6 );
    $self->is_open( TRUE );
    return $self;
 }
@@ -629,8 +622,8 @@ sub _open_file {
    $self->_assert and $self->assert_filepath;
    $self->_umask_push( $perms );
    $self->io_handle( IO::File->new( $path, $mode ) )
-      or $self->throw( error => 'File [_1] cannot open',
-                       args  => [ $path ], level => 6 );
+      or $self->_throw( error => 'File [_1] cannot open',
+                        args  => [ $path ], level => 6 );
    $self->_umask_pop;
    $self->is_open( TRUE );
    $self->set_binmode;
@@ -655,7 +648,7 @@ sub _print {
 
    for (@rest) {
       print {$self->io_handle} $_
-         or $self->throw( error => 'IO error [_1]', args  => [ $ERRNO ] );
+         or $self->_throw( error => 'IO error [_1]', args  => [ $ERRNO ] );
    }
 
    return $self;
@@ -717,8 +710,8 @@ sub _rename_atomic {
 
    if ($path and -f $path) {
       File::Copy::move( $path, $self->name )
-         or $self->throw( error => 'Cannot rename [_1] to [_2]: [_3]',
-                          args  => [ $path, $self->name, $ERRNO ] );
+         or $self->_throw( error => 'Cannot rename [_1] to [_2]: [_3]',
+                           args  => [ $path, $self->name, $ERRNO ] );
    }
 
    return;
@@ -729,7 +722,7 @@ sub rmdir {
 }
 
 sub rmtree {
-   my ($self, @rest) = @_; return File::Path::rmtree( $self->name, @rest );
+   my ($self, @rest) = @_; return File::Path::remove_tree( $self->name, @rest );
 }
 
 sub seek {
@@ -831,12 +824,10 @@ sub tempfile {
    return $self;
 }
 
-sub throw {
-   my ($self, @rest) = @_;
+sub _throw {
+   my ($self, @rest) = @_; eval { $self->unlock; };
 
-   eval { $self->unlock; }; $self->_exception_class->throw( @rest );
-
-   return; # Never reached
+   EXCEPTION_CLASS->throw( @rest ); return; # Not reached
 }
 
 sub touch {
@@ -922,7 +913,7 @@ File::DataClass::IO - Better IO syntax
 
 =head1 Version
 
-0.8.$Revision: 351 $
+0.9.$Revision: 368 $
 
 =head1 Synopsis
 
@@ -1483,9 +1474,9 @@ Create a randomly named temporary file in the I<name>
 directory. The file name is prefixed with the creating processes id
 and the temporary directory defaults to F</tmp>
 
-=head2 throw
+=head2 _throw
 
-Exposes the C<throw> method in the class exception class
+Exposes the C<throw> method in the exception class
 
 =head2 touch
 
