@@ -1,19 +1,19 @@
-# @(#)$Id: List.pm 351 2012-03-28 23:57:08Z pjf $
+# @(#)$Id: List.pm 368 2012-04-17 18:54:37Z pjf $
 
 package File::DataClass::List;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 351 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 368 $ =~ /\d+/gmx );
 
 use Moose;
+use MooseX::Types::Moose qw(ArrayRef Bool HashRef Undef);
+use File::DataClass::Constraints qw(Result);
 
-with qw(File::DataClass::Constraints);
-
-has 'found'  => is => 'ro', isa => 'Bool',     default => 0;
-has 'labels' => is => 'ro', isa => 'HashRef',  default => sub { return {} };
-has 'list'   => is => 'ro', isa => 'ArrayRef', default => sub { return [] };
-has 'result' => is => 'ro', isa => 'Maybe[F_DC_Result]';
+has 'found'  => is => 'ro', isa => Bool,     default => 0;
+has 'labels' => is => 'ro', isa => HashRef,  default => sub { return {} };
+has 'list'   => is => 'ro', isa => ArrayRef, default => sub { return [] };
+has 'result' => is => 'ro', isa => Result | Undef;
 
 __PACKAGE__->meta->make_immutable;
 
@@ -31,7 +31,7 @@ File::DataClass::List - List response class
 
 =head1 Version
 
-0.8.$Revision: 351 $
+0.9.$Revision: 368 $
 
 =head1 Synopsis
 
@@ -64,7 +64,7 @@ An array ref of element names
 
 =item B<result>
 
-Maybe an C<F_DC_Result> if the requested element was found
+Maybe an C<Result> if the requested element was found
 
 =back
 
