@@ -1,24 +1,28 @@
-# @(#)$Id: XML.pm 351 2012-03-28 23:57:08Z pjf $
+# @(#)$Id: XML.pm 368 2012-04-17 18:54:37Z pjf $
 
 package File::DataClass::Storage::XML;
 
 use strict;
 use namespace::autoclean;
-use version; our $VERSION = qv( sprintf '0.8.%d', q$Rev: 351 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.9.%d', q$Rev: 368 $ =~ /\d+/gmx );
 
 use File::DataClass::Constants;
+use File::DataClass::Constraints qw(HashRefOfBools);
+use MooseX::Types::Moose qw(ArrayRef Str);
 use XML::DTD;
 use Moose;
 
 extends qw(File::DataClass::Storage);
 
 has '+extn'     => default => q(.xml);
-has 'root_name' => is => 'ro', isa => 'Str',      default  => 'config';
-has '_arrays'   => is => 'rw', isa => 'F_DC_HashRefOfBools',
-   coerce       => TRUE,  init_arg => 'force_array',
-   default      => sub { return {} };
-has '_dtd'      => is => 'rw', isa => 'ArrayRef', init_arg => 'dtd',
-   default      => sub { return [] };
+
+has 'root_name' => is => 'ro', isa => Str,            default => 'config';
+
+has '_arrays'   => is => 'rw', isa => HashRefOfBools, default => sub { {} },
+   init_arg     => 'force_array',                     coerce  => TRUE;
+
+has '_dtd'      => is => 'rw', isa => ArrayRef,       default => sub { [] },
+   init_arg     => 'dtd';
 
 around '_meta_pack' => sub {
    my ($orig, $self, $args) = @_; my $packed = $self->$orig( $args );
@@ -111,7 +115,7 @@ File::DataClass::Storage::XML - Read/write XML data storage model
 
 =head1 Version
 
-0.8.$Revision: 351 $
+0.9.$Revision: 368 $
 
 =head1 Synopsis
 
